==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket3_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket3_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus3_clampState;

  private final int clampxminus3_filterPositionSensorValue;

  private final int clampxminus3_filterPresenceOffset2;

  private final String clampxminus3_filterPresenceStatus;

  private final int clampxminus3_lockSensorOffset1;

  private final int clampxminus3_lockSensorValue;

  private final String clampxminus3_lockStatus;

  private final String clampxplus3_clampState;

  private final int clampxplus3_filterPositionSensorValue;

  private final int clampxplus3_filterPresenceOffset2;

  private final String clampxplus3_filterPresenceStatus;

  private final int clampxplus3_lockSensorOffset1;

  private final int clampxplus3_lockSensorValue;

  private final String clampxplus3_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final int filterID;

  private final String ioStatus;

  public Fcs_Carousel_Socket3_TrendingTelemetry(boolean atStandby, String clampxminus3_clampState,
      int clampxminus3_filterPositionSensorValue, int clampxminus3_filterPresenceOffset2,
      String clampxminus3_filterPresenceStatus, int clampxminus3_lockSensorOffset1,
      int clampxminus3_lockSensorValue, String clampxminus3_lockStatus,
      String clampxplus3_clampState, int clampxplus3_filterPositionSensorValue,
      int clampxplus3_filterPresenceOffset2, String clampxplus3_filterPresenceStatus,
      int clampxplus3_lockSensorOffset1, int clampxplus3_lockSensorValue,
      String clampxplus3_lockStatus, String clampsState, boolean empty, int filterID,
      String ioStatus) {
    this.atStandby = atStandby;
    this.clampxminus3_clampState = clampxminus3_clampState;
    this.clampxminus3_filterPositionSensorValue = clampxminus3_filterPositionSensorValue;
    this.clampxminus3_filterPresenceOffset2 = clampxminus3_filterPresenceOffset2;
    this.clampxminus3_filterPresenceStatus = clampxminus3_filterPresenceStatus;
    this.clampxminus3_lockSensorOffset1 = clampxminus3_lockSensorOffset1;
    this.clampxminus3_lockSensorValue = clampxminus3_lockSensorValue;
    this.clampxminus3_lockStatus = clampxminus3_lockStatus;
    this.clampxplus3_clampState = clampxplus3_clampState;
    this.clampxplus3_filterPositionSensorValue = clampxplus3_filterPositionSensorValue;
    this.clampxplus3_filterPresenceOffset2 = clampxplus3_filterPresenceOffset2;
    this.clampxplus3_filterPresenceStatus = clampxplus3_filterPresenceStatus;
    this.clampxplus3_lockSensorOffset1 = clampxplus3_lockSensorOffset1;
    this.clampxplus3_lockSensorValue = clampxplus3_lockSensorValue;
    this.clampxplus3_lockStatus = clampxplus3_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterID = filterID;
    this.ioStatus = ioStatus;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus3_clampState() {
    return clampxminus3_clampState;
  }

  public int getClampxminus3_filterPositionSensorValue() {
    return clampxminus3_filterPositionSensorValue;
  }

  public int getClampxminus3_filterPresenceOffset2() {
    return clampxminus3_filterPresenceOffset2;
  }

  public String getClampxminus3_filterPresenceStatus() {
    return clampxminus3_filterPresenceStatus;
  }

  public int getClampxminus3_lockSensorOffset1() {
    return clampxminus3_lockSensorOffset1;
  }

  public int getClampxminus3_lockSensorValue() {
    return clampxminus3_lockSensorValue;
  }

  public String getClampxminus3_lockStatus() {
    return clampxminus3_lockStatus;
  }

  public String getClampxplus3_clampState() {
    return clampxplus3_clampState;
  }

  public int getClampxplus3_filterPositionSensorValue() {
    return clampxplus3_filterPositionSensorValue;
  }

  public int getClampxplus3_filterPresenceOffset2() {
    return clampxplus3_filterPresenceOffset2;
  }

  public String getClampxplus3_filterPresenceStatus() {
    return clampxplus3_filterPresenceStatus;
  }

  public int getClampxplus3_lockSensorOffset1() {
    return clampxplus3_lockSensorOffset1;
  }

  public int getClampxplus3_lockSensorValue() {
    return clampxplus3_lockSensorValue;
  }

  public String getClampxplus3_lockStatus() {
    return clampxplus3_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public int getFilterID() {
    return filterID;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket3_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus3_clampState=" + clampxminus3_clampState +
        ", clampxminus3_filterPositionSensorValue=" + clampxminus3_filterPositionSensorValue +
        ", clampxminus3_filterPresenceOffset2=" + clampxminus3_filterPresenceOffset2 +
        ", clampxminus3_filterPresenceStatus=" + clampxminus3_filterPresenceStatus +
        ", clampxminus3_lockSensorOffset1=" + clampxminus3_lockSensorOffset1 +
        ", clampxminus3_lockSensorValue=" + clampxminus3_lockSensorValue +
        ", clampxminus3_lockStatus=" + clampxminus3_lockStatus +
        ", clampxplus3_clampState=" + clampxplus3_clampState +
        ", clampxplus3_filterPositionSensorValue=" + clampxplus3_filterPositionSensorValue +
        ", clampxplus3_filterPresenceOffset2=" + clampxplus3_filterPresenceOffset2 +
        ", clampxplus3_filterPresenceStatus=" + clampxplus3_filterPresenceStatus +
        ", clampxplus3_lockSensorOffset1=" + clampxplus3_lockSensorOffset1 +
        ", clampxplus3_lockSensorValue=" + clampxplus3_lockSensorValue +
        ", clampxplus3_lockStatus=" + clampxplus3_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterID=" + filterID +", ioStatus=" + ioStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus3_clampState;

    private int clampxminus3_filterPositionSensorValue;

    private int clampxminus3_filterPresenceOffset2;

    private String clampxminus3_filterPresenceStatus;

    private int clampxminus3_lockSensorOffset1;

    private int clampxminus3_lockSensorValue;

    private String clampxminus3_lockStatus;

    private String clampxplus3_clampState;

    private int clampxplus3_filterPositionSensorValue;

    private int clampxplus3_filterPresenceOffset2;

    private String clampxplus3_filterPresenceStatus;

    private int clampxplus3_lockSensorOffset1;

    private int clampxplus3_lockSensorValue;

    private String clampxplus3_lockStatus;

    private String clampsState;

    private boolean empty;

    private int filterID;

    private String ioStatus;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus3_clampState(String clampxminus3_clampState) {
      this.clampxminus3_clampState = clampxminus3_clampState;
      return this;
    }

    public Builder clampxminus3_filterPositionSensorValue(
        int clampxminus3_filterPositionSensorValue) {
      this.clampxminus3_filterPositionSensorValue = clampxminus3_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus3_filterPresenceOffset2(int clampxminus3_filterPresenceOffset2) {
      this.clampxminus3_filterPresenceOffset2 = clampxminus3_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus3_filterPresenceStatus(String clampxminus3_filterPresenceStatus) {
      this.clampxminus3_filterPresenceStatus = clampxminus3_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus3_lockSensorOffset1(int clampxminus3_lockSensorOffset1) {
      this.clampxminus3_lockSensorOffset1 = clampxminus3_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus3_lockSensorValue(int clampxminus3_lockSensorValue) {
      this.clampxminus3_lockSensorValue = clampxminus3_lockSensorValue;
      return this;
    }

    public Builder clampxminus3_lockStatus(String clampxminus3_lockStatus) {
      this.clampxminus3_lockStatus = clampxminus3_lockStatus;
      return this;
    }

    public Builder clampxplus3_clampState(String clampxplus3_clampState) {
      this.clampxplus3_clampState = clampxplus3_clampState;
      return this;
    }

    public Builder clampxplus3_filterPositionSensorValue(
        int clampxplus3_filterPositionSensorValue) {
      this.clampxplus3_filterPositionSensorValue = clampxplus3_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus3_filterPresenceOffset2(int clampxplus3_filterPresenceOffset2) {
      this.clampxplus3_filterPresenceOffset2 = clampxplus3_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus3_filterPresenceStatus(String clampxplus3_filterPresenceStatus) {
      this.clampxplus3_filterPresenceStatus = clampxplus3_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus3_lockSensorOffset1(int clampxplus3_lockSensorOffset1) {
      this.clampxplus3_lockSensorOffset1 = clampxplus3_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus3_lockSensorValue(int clampxplus3_lockSensorValue) {
      this.clampxplus3_lockSensorValue = clampxplus3_lockSensorValue;
      return this;
    }

    public Builder clampxplus3_lockStatus(String clampxplus3_lockStatus) {
      this.clampxplus3_lockStatus = clampxplus3_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterID(int filterID) {
      this.filterID = filterID;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Fcs_Carousel_Socket3_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket3_TrendingTelemetry(atStandby, clampxminus3_clampState, clampxminus3_filterPositionSensorValue, clampxminus3_filterPresenceOffset2, clampxminus3_filterPresenceStatus, clampxminus3_lockSensorOffset1, clampxminus3_lockSensorValue, clampxminus3_lockStatus, clampxplus3_clampState, clampxplus3_filterPositionSensorValue, clampxplus3_filterPresenceOffset2, clampxplus3_filterPresenceStatus, clampxplus3_lockSensorOffset1, clampxplus3_lockSensorValue, clampxplus3_lockStatus, clampsState, empty, filterID, ioStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.1-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket3_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket3_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus3_clampState;

  private final int clampxminus3_filterPositionSensorValue;

  private final int clampxminus3_filterPresenceOffset2;

  private final String clampxminus3_filterPresenceStatus;

  private final int clampxminus3_lockSensorOffset1;

  private final int clampxminus3_lockSensorValue;

  private final String clampxminus3_lockStatus;

  private final String clampxplus3_clampState;

  private final int clampxplus3_filterPositionSensorValue;

  private final int clampxplus3_filterPresenceOffset2;

  private final String clampxplus3_filterPresenceStatus;

  private final int clampxplus3_lockSensorOffset1;

  private final int clampxplus3_lockSensorValue;

  private final String clampxplus3_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final String filterName;

  private final String ioStatus;

  private final int socketID;

  public Fcs_Carousel_Socket3_TrendingTelemetry(boolean atStandby, String clampxminus3_clampState,
      int clampxminus3_filterPositionSensorValue, int clampxminus3_filterPresenceOffset2,
      String clampxminus3_filterPresenceStatus, int clampxminus3_lockSensorOffset1,
      int clampxminus3_lockSensorValue, String clampxminus3_lockStatus,
      String clampxplus3_clampState, int clampxplus3_filterPositionSensorValue,
      int clampxplus3_filterPresenceOffset2, String clampxplus3_filterPresenceStatus,
      int clampxplus3_lockSensorOffset1, int clampxplus3_lockSensorValue,
      String clampxplus3_lockStatus, String clampsState, boolean empty, String filterName,
      String ioStatus, int socketID) {
    this.atStandby = atStandby;
    this.clampxminus3_clampState = clampxminus3_clampState;
    this.clampxminus3_filterPositionSensorValue = clampxminus3_filterPositionSensorValue;
    this.clampxminus3_filterPresenceOffset2 = clampxminus3_filterPresenceOffset2;
    this.clampxminus3_filterPresenceStatus = clampxminus3_filterPresenceStatus;
    this.clampxminus3_lockSensorOffset1 = clampxminus3_lockSensorOffset1;
    this.clampxminus3_lockSensorValue = clampxminus3_lockSensorValue;
    this.clampxminus3_lockStatus = clampxminus3_lockStatus;
    this.clampxplus3_clampState = clampxplus3_clampState;
    this.clampxplus3_filterPositionSensorValue = clampxplus3_filterPositionSensorValue;
    this.clampxplus3_filterPresenceOffset2 = clampxplus3_filterPresenceOffset2;
    this.clampxplus3_filterPresenceStatus = clampxplus3_filterPresenceStatus;
    this.clampxplus3_lockSensorOffset1 = clampxplus3_lockSensorOffset1;
    this.clampxplus3_lockSensorValue = clampxplus3_lockSensorValue;
    this.clampxplus3_lockStatus = clampxplus3_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterName = filterName;
    this.ioStatus = ioStatus;
    this.socketID = socketID;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus3_clampState() {
    return clampxminus3_clampState;
  }

  public int getClampxminus3_filterPositionSensorValue() {
    return clampxminus3_filterPositionSensorValue;
  }

  public int getClampxminus3_filterPresenceOffset2() {
    return clampxminus3_filterPresenceOffset2;
  }

  public String getClampxminus3_filterPresenceStatus() {
    return clampxminus3_filterPresenceStatus;
  }

  public int getClampxminus3_lockSensorOffset1() {
    return clampxminus3_lockSensorOffset1;
  }

  public int getClampxminus3_lockSensorValue() {
    return clampxminus3_lockSensorValue;
  }

  public String getClampxminus3_lockStatus() {
    return clampxminus3_lockStatus;
  }

  public String getClampxplus3_clampState() {
    return clampxplus3_clampState;
  }

  public int getClampxplus3_filterPositionSensorValue() {
    return clampxplus3_filterPositionSensorValue;
  }

  public int getClampxplus3_filterPresenceOffset2() {
    return clampxplus3_filterPresenceOffset2;
  }

  public String getClampxplus3_filterPresenceStatus() {
    return clampxplus3_filterPresenceStatus;
  }

  public int getClampxplus3_lockSensorOffset1() {
    return clampxplus3_lockSensorOffset1;
  }

  public int getClampxplus3_lockSensorValue() {
    return clampxplus3_lockSensorValue;
  }

  public String getClampxplus3_lockStatus() {
    return clampxplus3_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  public int getSocketID() {
    return socketID;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket3_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus3_clampState=" + clampxminus3_clampState +
        ", clampxminus3_filterPositionSensorValue=" + clampxminus3_filterPositionSensorValue +
        ", clampxminus3_filterPresenceOffset2=" + clampxminus3_filterPresenceOffset2 +
        ", clampxminus3_filterPresenceStatus=" + clampxminus3_filterPresenceStatus +
        ", clampxminus3_lockSensorOffset1=" + clampxminus3_lockSensorOffset1 +
        ", clampxminus3_lockSensorValue=" + clampxminus3_lockSensorValue +
        ", clampxminus3_lockStatus=" + clampxminus3_lockStatus +
        ", clampxplus3_clampState=" + clampxplus3_clampState +
        ", clampxplus3_filterPositionSensorValue=" + clampxplus3_filterPositionSensorValue +
        ", clampxplus3_filterPresenceOffset2=" + clampxplus3_filterPresenceOffset2 +
        ", clampxplus3_filterPresenceStatus=" + clampxplus3_filterPresenceStatus +
        ", clampxplus3_lockSensorOffset1=" + clampxplus3_lockSensorOffset1 +
        ", clampxplus3_lockSensorValue=" + clampxplus3_lockSensorValue +
        ", clampxplus3_lockStatus=" + clampxplus3_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterName=" + filterName +", ioStatus=" + ioStatus +
        ", socketID=" + socketID +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus3_clampState;

    private int clampxminus3_filterPositionSensorValue;

    private int clampxminus3_filterPresenceOffset2;

    private String clampxminus3_filterPresenceStatus;

    private int clampxminus3_lockSensorOffset1;

    private int clampxminus3_lockSensorValue;

    private String clampxminus3_lockStatus;

    private String clampxplus3_clampState;

    private int clampxplus3_filterPositionSensorValue;

    private int clampxplus3_filterPresenceOffset2;

    private String clampxplus3_filterPresenceStatus;

    private int clampxplus3_lockSensorOffset1;

    private int clampxplus3_lockSensorValue;

    private String clampxplus3_lockStatus;

    private String clampsState;

    private boolean empty;

    private String filterName;

    private String ioStatus;

    private int socketID;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus3_clampState(String clampxminus3_clampState) {
      this.clampxminus3_clampState = clampxminus3_clampState;
      return this;
    }

    public Builder clampxminus3_filterPositionSensorValue(
        int clampxminus3_filterPositionSensorValue) {
      this.clampxminus3_filterPositionSensorValue = clampxminus3_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus3_filterPresenceOffset2(int clampxminus3_filterPresenceOffset2) {
      this.clampxminus3_filterPresenceOffset2 = clampxminus3_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus3_filterPresenceStatus(String clampxminus3_filterPresenceStatus) {
      this.clampxminus3_filterPresenceStatus = clampxminus3_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus3_lockSensorOffset1(int clampxminus3_lockSensorOffset1) {
      this.clampxminus3_lockSensorOffset1 = clampxminus3_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus3_lockSensorValue(int clampxminus3_lockSensorValue) {
      this.clampxminus3_lockSensorValue = clampxminus3_lockSensorValue;
      return this;
    }

    public Builder clampxminus3_lockStatus(String clampxminus3_lockStatus) {
      this.clampxminus3_lockStatus = clampxminus3_lockStatus;
      return this;
    }

    public Builder clampxplus3_clampState(String clampxplus3_clampState) {
      this.clampxplus3_clampState = clampxplus3_clampState;
      return this;
    }

    public Builder clampxplus3_filterPositionSensorValue(
        int clampxplus3_filterPositionSensorValue) {
      this.clampxplus3_filterPositionSensorValue = clampxplus3_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus3_filterPresenceOffset2(int clampxplus3_filterPresenceOffset2) {
      this.clampxplus3_filterPresenceOffset2 = clampxplus3_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus3_filterPresenceStatus(String clampxplus3_filterPresenceStatus) {
      this.clampxplus3_filterPresenceStatus = clampxplus3_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus3_lockSensorOffset1(int clampxplus3_lockSensorOffset1) {
      this.clampxplus3_lockSensorOffset1 = clampxplus3_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus3_lockSensorValue(int clampxplus3_lockSensorValue) {
      this.clampxplus3_lockSensorValue = clampxplus3_lockSensorValue;
      return this;
    }

    public Builder clampxplus3_lockStatus(String clampxplus3_lockStatus) {
      this.clampxplus3_lockStatus = clampxplus3_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Builder socketID(int socketID) {
      this.socketID = socketID;
      return this;
    }

    public Fcs_Carousel_Socket3_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket3_TrendingTelemetry(atStandby, clampxminus3_clampState, clampxminus3_filterPositionSensorValue, clampxminus3_filterPresenceOffset2, clampxminus3_filterPresenceStatus, clampxminus3_lockSensorOffset1, clampxminus3_lockSensorValue, clampxminus3_lockStatus, clampxplus3_clampState, clampxplus3_filterPositionSensorValue, clampxplus3_filterPresenceOffset2, clampxplus3_filterPresenceStatus, clampxplus3_lockSensorOffset1, clampxplus3_lockSensorValue, clampxplus3_lockStatus, clampsState, empty, filterName, ioStatus, socketID);
    }
  }
}
